@@ -15,7 +15,7 @@ using a Metropolis-Hastings Monte Carlo algorithm
 	and is copyrighted. Of course, we do not guarantee that the software
 	works and are not responsible for any damage you may cause or have.
 
-$Id: aic.c 633 2007-03-06 04:14:07Z beerli $ 
+$Id: aic.c 1088 2007-12-21 20:50:44Z beerli $ 
 -------------------------------------------------------*/
 
 #include "migration.h"
@@ -295,7 +295,7 @@ void fast_aic_score (aic_fmt ** aicvec, long *aicnum, nr_fmt * nr,
   //#ifdef MYREAL == float
   //MYREAL numbermax = FLT_MAX ;
   //#else
-  const MYREAL numbermax = DBL_MAX ;
+  const MYREAL numbermax = MYREAL_MAX ;
   //#endif
 
     long m, ii;
@@ -591,7 +591,7 @@ legal_pattern (char *matrix, long numpop)
         m2mm (i, numpop, &from, &to);
         if (oldto != to)
         {
-            if (summ < eps)
+	  if (fabs(summ)< eps )
                 return FALSE;
             oldto = to;
             summ = 0;
