@@ -9,12 +9,12 @@
  aic model  test   R O U T I N E S 
  
  Peter Beerli 2001, Seattle
- beerli@csit.fsu.edu
+ beerli@scs.fsu.edu
  
 Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
 Copyright 2003-2004 Peter Beerli, Tallahassee FL
  
-$Id: aic.h 175 2005-12-02 14:51:23Z beerli $
+$Id: aic.h 514 2006-11-09 20:14:08Z beerli $
 -------------------------------------------------------*/
 #include "migration.h"
 
