@@ -22,7 +22,7 @@ Copyright 2003-2007 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: data.c 1172 2008-02-19 20:12:21Z beerli $
+$Id: data.c 1220 2008-03-28 01:36:29Z beerli $
  
 -------------------------------------------------------*/
 /*! \file data.c
@@ -1779,15 +1779,18 @@ read_date_fromfile (FILE * datefile, data_fmt *data, option_fmt *options, long n
     long locus;
     long ind;
     MYREAL oldest = 0. ;
+    MYREAL youngest = DBL_MAX;
     MYREAL temp;
     char *name;
+    boolean backward = TRUE;
     name = (char *) mycalloc(LINESIZE,sizeof(char));
     if (datefile != NULL)
     {
         FGETS (input, LINESIZE, datefile); //title line
 	while(input[0]=='#')
 	  FGETS(input,LINESIZE,datefile);
- 
+	if(input[0]=='F') //this checks the direction of time
+	  backward=FALSE; 
 	fprintf(stdout,"\n%i> Tip dates from file %s\n----------------------------------------\n", myID, options->datefilename);	
 	fprintf(stdout,"Generation time:            %f\n", options->generation_year);
 	for(pop=0;pop<data->numpop;pop++)
@@ -1816,6 +1819,28 @@ read_date_fromfile (FILE * datefile, data_fmt *data, option_fmt *options, long n
 		    strcpy(data->sampledates[pop][locus][ind].name, name);
 		    if(oldest < temp)
 		      oldest = temp;
+		    if(youngest > temp)
+		      youngest = temp;
+		  }
+	      }
+	  }
+	// are the times forward or backward?
+	for(pop=0;pop<data->numpop;pop++)
+	  {
+	    for (locus=0; locus < data->loci; locus++)
+	      {
+		for(ind=0; ind < data->numind[pop][locus]; ind++)
+		  {
+		    if(backward)
+		      {
+			data->sampledates[pop][locus][ind].date =
+			  data->sampledates[pop][locus][ind].date - youngest;
+		      }
+		    else
+		      {
+			data->sampledates[pop][locus][ind].date = oldest -
+			  data->sampledates[pop][locus][ind].date;
+		      }
 		  }
 	      }
 	  }
