@@ -17,16 +17,16 @@
   
 Copyright 2002 Peter Beerli and Joseph Felsenstein
  
-$Id: definitions.h 1156 2008-02-14 18:30:18Z beerli $
+$Id: definitions.h 1224 2008-03-28 23:24:17Z beerli $
  
   *----------------------------------------------------------------
   */
 #ifndef MIGRATEVERSION
-#define MIGRATEVERSION "2.4.2"
+#define MIGRATEVERSION "2.4.4"
 #else
 #ifdef SGI
 #undef MIGRATEVERSION
-#define MIGRATEVERSION "2.4.2"
+#define MIGRATEVERSION "2.4.4"
 #endif
 #endif
 #ifndef MIGRATESUBVERSION
@@ -160,6 +160,8 @@ $Id: definitions.h 1156 2008-02-14 18:30:18Z beerli $
 #define DIVFILENUM 24
 #define TIPDATEFILE "datefile"
 #define TIPDATEFILENUM 25
+#define MIXFILE "mixfile"
+#define MIXFILENUM 26
 #define BAYESNUMBIN 200
 #define PRETTY_MAX 0
 #define PRETTY_P99 1
