@@ -26,7 +26,7 @@
 *   works and am not responsible for any damage you may cause or have.
 *
 */
-/* $Id: main.c 1160 2008-02-16 15:41:22Z beerli $*/
+/* $Id: main.c 1228 2008-04-02 12:47:16Z beerli $*/
 
 #include "migration.h"
 #include "sighandler.h"
@@ -267,6 +267,11 @@ void get_mighistdata (world_fmt * world, option_fmt * options);
 
 void change_longsum_times (world_fmt * world);
 
+boolean  check_parmfile(long argcount, char **arguments, char *parmfilename);
+boolean set_usemenu(boolean usemenu, boolean fromparmfile);
+void check_bayes_options(option_fmt *options);
+void reset_bayesmdimfile(world_fmt *world, option_fmt *options);
+
 extern void unset_penalizer_function (boolean inprofiles);
 
 ///
@@ -275,6 +280,9 @@ enum override_enum
   {
     OVERRIDE_NO, OVERRIDE_MENU, OVERRIDE_NOMENU
   };
+
+
+
 ///
 /// the program migrate calculates migration rates and population sizes
 /// from genetic data, it allows for a wide variety of data types and many options
@@ -284,7 +292,6 @@ main (int argc, char **argv)
 {
   // for debug to stop at first statement of main() char c;
   int usemenu = OVERRIDE_NO;
-  int argument;
     char type = 's';
     data_fmt *data;
 #ifdef INTEGRATEDLIKE
@@ -303,11 +310,17 @@ main (int argc, char **argv)
     nice (10);			//nice value arbitrarily set to 10, 5 is still nice, 0 is standard
 #endif
     // puts(argv[0]);
+
+    //---------------------------------------------------------------------------------------------
+    // windows specific code for pretty printing
 #ifdef PRETTY
 #ifdef WIN32
     set_haru_handler();
 #endif
 #endif
+
+    //---------------------------------------------------------------------------------------------
+    // MPI initialisation
 #ifdef MPI
     // parallel version
     filenum = 0;			//setting up the filename database so that worker node can write back to master
@@ -319,35 +332,29 @@ main (int argc, char **argv)
     server = MASTER;		//server ID
     MPI_Group_excl (world_group, 1, &server, &worker_group);
 
-    //MPI_Comm_create (comm_world, worker_group, &comm_workers);
-    //fprintf(stderr,"MIGRATE 2.2 RUN (after comm create comm_workers)\n");
-    //if (myID != MASTER)
-    //    MPI_Comm_rank (comm_workers, &myRepID);
-    //    fprintf(stderr,"%i> MIGRATE 2.2 RUN\n",myID);
-    // locus counter for workers, this should report the number of loci 
-    // each nodes really works on
     locidone = 0;
-    //if(myID==0)
-    //  c=fgetc(stdin);
-    //MYMPIBARRIER (comm_world);
-
-    //does not work?    set_memory_limit(5,50);
 
 #ifdef SLOWNET
-    // slow network parallel version
+    // slow network parallel version -- this will turn into the standard version
     profiledone = 0;
     which_calc_like (SINGLELOCUS);
 #endif
+
 #else /*MPI*/
     //scalar version of migrate
     myID = MASTER;
     numcpu = 1;
 #endif /*MPI*/
+
+    // debug code for memory problems
 #ifdef MEMDEBUG
     totalsize = 0 ;
     memfile = fopen("memoryfile","w+");
     gettimeofday(&memt_start, NULL);
 #endif
+
+    //---------------------------------------------------------------------------------------------
+    // initialization of main container and random number parts
     seed = (long *) mymalloc (sizeof (long) * 3);
     newseed = (long *) mymalloc (sizeof (long) * 3);
     generator = (char *) mycalloc (1,sizeof(char) * 80);
@@ -367,190 +374,115 @@ main (int argc, char **argv)
     
     // parmfile and menu
     init_options (options);
+
+    //---------------------------------------------------------------------------------------------
+    // master initializations, this works for both parallel and single-cpu version
     if (myID == MASTER)
-    {
-	if (argc > 1)			
-	  // user uses another parmfile
-	  // addition of an option to override the menu command in the parmfile
-	  // migrate-n -menu ==> use menu independent of the parmfile setting
-	  // migrate-n -nomenu ==> does use menu even if parmfile says so
-	  {
-	    argument = 1;
-	    while(argument < argc)
-	      {
-		//fprintf(stderr,"<|%s|>\n",argv[argument]);
-		//fflush(stderr);
-		if(argv[argument][0]!='-')
-		  {
-		    strncpy (options->parmfilename, argv[argument], 
-			     (long) strlen (argv[argument]) + 1);
-		  }
-		else
-		  {
-		    if(strcmp(argv[argument],"-menu")==0)
-		      {
-			usemenu = OVERRIDE_MENU;
-		      }
-		    else
-		      {
-			if(strcmp(argv[argument],"-nomenu")==0)
-			  {
-			    usemenu = OVERRIDE_NOMENU;
-			  }
-		      }
-		  }
-		argument++;
-	      }
-	  }
-        read_options_master (options);
-	switch(usemenu)
-	  {
-	  case OVERRIDE_MENU:
-	    options->menu = TRUE;
-	    break;
-	  case OVERRIDE_NOMENU:
-	    options->menu = FALSE;
-	    break;
-	  default:
-	    break;
-	  }
-        print_menu_title (stdout, options);
-        get_menu (options);
-        if (options->bayes_infer)
-	  {
-	    if(options->schains>0)
-	      {
-		//		fprintf(stdout,"NOTICE: with Bayesian inference no short chains are allowed, setting them to ZERO\n");
-		options->schains = 0;
-	      }
-	    if(options->lchains>1 || options->lchains < 1)
-	      {
-		fprintf(stdout,"NOTICE: with Bayesian inference, most efficient runs are with 1 long chain,\nsetting the long chain to 1\n");
-		options->lchains = 1;
-	      };
-	  }
+      {
+	usemenu = check_parmfile(argc,argv,options->parmfilename);
+	read_options_master (options);
+	options->menu = set_usemenu(usemenu, options->menu);
+	print_menu_title (stdout, options);
+	get_menu (options);
+	check_bayes_options(options);
 #ifdef MPI        
 	MYMPIBARRIER (comm_world);
         broadcast_options_master (options);
 #endif
-    }
+      }
     else
-    {
+      {
 #ifdef MPI
-    MYMPIBARRIER (comm_world);
-        broadcast_options_worker (options);
+	MYMPIBARRIER (comm_world);
+	broadcast_options_worker (options);
 #endif
-        //options->writelog = FALSE;
-        options->menu = FALSE;
-    }
-    // initialization and data reading phase
-    if(options->heating)
-      {
-	usize = MAX (1, options->heated_chains);
-      }
-    else
-      {
-	usize = 1;
+	options->menu = FALSE;
       }
+    
+    //---------------------------------------------------------------------------------------------
+    // data initialization and data reading phase
+    usize = (options->heating ? ( MAX (1, options->heated_chains)) : 1 );
     universe = (world_fmt **) myrealloc (universe, usize * sizeof (world_fmt *));
     
     init_files (EARTH, data, options);
     
     if (options->writelog && myID == MASTER)
-    {
+      {
         print_menu_title (options->logfile, options);
-    }
+      }
     
     EARTH->repkind = SINGLECHAIN;
     //fprintf(stderr,"myID=%i myRepID=%i\n",myID, myRepID);    
     unset_penalizer_function (FALSE);	// install penalizer for far jumps in MCMC
     
+    //---------------------------------------------------------------------------------------------
     // sampling phase
-    if (!options->readsum)
-    {
-        //MCMC sampling
+    if (!options->readsum) // all go here except when reading old runs
+      {
         run_sampler (options, data, universe, usize, &outfilepos, &Gmax);
-    }
+      }
     else
-    {
-      if(options->bayes_infer)
-	{
-	  //	  analyze_oldbayesdata(EARTH, options, data, &outfilepos);
-	}
-      else
-	{
-        //reanalyze sumfile
-        Gmax = analyze_olddata (EARTH, options, data, &outfilepos);
-	}
-    }
+      {
+	if(options->bayes_infer)
+	  {
+	    // reanalyze old or borken bayesrun [not ready yet]
+	    // analyze_oldbayesdata(EARTH, options, data, &outfilepos);
+	  }
+	else
+	  {
+	    //reanalyze sumfile
+	    Gmax = analyze_olddata (EARTH, options, data, &outfilepos);
+	  }
+      }
     unset_penalizer_function (TRUE);
+    
+    //---------------------------------------------------------------------------------------------
+    // combining phase for multiple loci and replicates
 #ifdef MPI
     //with MPI:the workers stay here much longer than the Master
     combine_loci_mpi (type, options, EARTH, &Gmax);
 #else
     combine_loci_standard (type, options, EARTH, &Gmax);
 #endif
-
+    // bayes inference 
     if (options->bayes_infer)
-    {
-      if(EARTH->options->has_bayesmdimfile)
-	{
-	  get_bayeshist (EARTH, options); // this is transferring some material but
-	  // the parameter file is not filled in anymore [-> small data block]
-	  // save parameters in file and reload
-	  if(myID==MASTER)
-	    {
-	      FClose(EARTH->bayesmdimfile);
-	      openfile(&EARTH->bayesmdimfile, options->bayesmdimfilename,"r+",NULL);
-	      read_bayes_fromfile(EARTH->bayesmdimfile,EARTH, options);
-	      for(locus=0;locus<EARTH->loci;locus++)
-		{
-		  if(EARTH->data->skiploci[locus])
-		    continue;
-		  if(EARTH->bayes->histogram[locus].results == NULL)
-		    {
-		      EARTH->data->skiploci[locus] = TRUE;
-		      continue;
-		    }
-		  calc_hpd_credibility(EARTH->bayes, locus, EARTH->numpop2 + EARTH->bayes->mu);
-		}
-	    }
-	}
-      else
-	{
-	  // keep everything in RAM
-	  get_bayeshist (EARTH, options);
-	}
-    }
+      {
+	// if bayes intermediate data recording is ON then reset the file
+	// for reading for printing and combining, else use the material still in RAM
+	reset_bayesmdimfile(EARTH, options);
+      }
     else
-    {
+      {
         // gather the treedata(1) into sumfile or from worker nodes
         get_treedata (EARTH, options);
-    }
-    // printing of results
+      }
+
+    //---------------------------------------------------------------------------------------------
+    // printing main results
     if (myID == MASTER)
-    {
-        if (options->bayes_infer)
-            bayes_stat (EARTH);
-        else
-        {
-            print_list (universe, options, data);
-#ifdef PRETTY
-	    pdf_print_results (&page_height, universe, options, data);
-	    //	    pdf_print_mcmctable(&page_height, page_width, EARTH, data, options);
-#endif
-            if (EARTH->options->gamma)
-                print_alpha_curve (EARTH, EARTH->atl, &Gmax);
+      {
+	if (options->bayes_infer)
+	  {
+	    // printe bayes inference main table
+	    bayes_stat (EARTH);
+	  }
+	else
+	  {
+	    // print ML table
+	    print_list (universe, options, data);
+	    print_alpha_curve (EARTH, EARTH->atl, &Gmax);
 	    if(options->printcov)
 	      print_cov(EARTH, EARTH->numpop, EARTH->loci, EARTH->cov);
-            fflush (EARTH->outfile);
-            if (EARTH->options->lratio->counter > 0)
-                print_lratio_test (EARTH, &Gmax);
-            if (options->aic)
-                akaike_information (EARTH, &Gmax);
-        }
+	    if (EARTH->options->lratio->counter > 0)
+	      print_lratio_test (EARTH, &Gmax);
+	    if (options->aic)
+	      akaike_information (EARTH, &Gmax);
+	  }
+	fflush (EARTH->outfile);
+	//---------------------------------------------------------------------------------------------
+	// printing additional results
 #ifdef MPI
-        get_mighistdata (EARTH, options);
+	get_mighistdata (EARTH, options);
 #endif
 	if(options->skyline && options->bayes_infer)
 	  print_expected_values(EARTH);       
@@ -560,169 +492,151 @@ main (int argc, char **argv)
 #ifdef PRETTY
 	    pdf_histogram_legend();
 #endif
-	  }        
-
-
+	  }              
 #ifdef UEP
-        // print UEP probabilities
-        if (options->uep)
-            analyze_uep (EARTH);
+	// print UEP probabilities
+	if (options->uep)
+	  analyze_uep (EARTH);
 #endif
-        
-        
         // profile tables
         unset_penalizer_function (TRUE);	//now we calculate profile and shut down
-                                            // the penalizing of far jumps in the maximizer function
-    }
-
+	// the penalizing of far jumps in the maximizer function
+      } // end of printing main tables and histograms
+    
 #ifdef NEXUSTREE
     if (EARTH->options->treeprint == LASTCHAIN)
       {
 	FPRINTF(EARTH->treefile,"\nend;\n");
       }
 #endif
+
 #ifdef SLOWNET
-    //    if(myID == MASTER)
-    //{
-        //if there are many loci but only few parameters to estimate
-        // this will be still slow and therefore saturating the network
-        // with parameter requests may still be the better solution
-        // for some - compile using make mpi instead make mpis
-        which_calc_like (PROFILE);
-        if (myID == MASTER)
-        {
-            // release the workers from the mpi_maximize_worker() function.
-            // the workers will stop working on locus-likelihoods and advance to profiles
-            mpi_send_stop (EARTH);
-        }
-#ifndef INTEGRATEDLIKE    
-	//        if (!options->bayes_infer)
-	//  {
-#endif
-	//   if (EARTH->options->lratio->counter > 0)
-	//      print_lratio_test (EARTH, &Gmax);
-	//    if (options->aic)
-	//      akaike_information (EARTH, &Gmax);
-	//    profile_tables (options, EARTH, &Gmax);
-#ifndef INTEGRATEDLIKE    
-	//  }
-#endif
+    which_calc_like (PROFILE);
+    if (myID == MASTER)
+      {
+	// release the workers from the mpi_maximize_worker() function.
+	// the workers will stop working on locus-likelihoods and advance to profiles
+	mpi_send_stop (EARTH);
+      }
+    if (!options->bayes_infer)
+      {
+	profile_tables (options, EARTH, &Gmax);
+      }
 #else  /* SLOWNET*/
-
-        if (myID == MASTER)
-        {
+    if (myID == MASTER)
+      {
 #ifdef INTEGRATEDLIKE
-	  if(options->integrated_like)
-	     {
-	       maxreplicate = (options->replicate
-			       && options->replicatenum >
-			       0) ? options->replicatenum : 1;
-	       print_theta0(stdout, EARTH, maxreplicate);
-
-	       if (EARTH->options->lratio->counter > 0)
-		 print_lratio_test (EARTH, &Gmax);
-	       if (options->aic)
-		 akaike_information (EARTH, &Gmax);
-	       
-	       profile_tables (options, EARTH, &Gmax);
-	     }
+	if(options->integrated_like)
+	  {
+	    maxreplicate = (options->replicate
+			    && options->replicatenum >
+			    0) ? options->replicatenum : 1;
+	    print_theta0(stdout, EARTH, maxreplicate);
+	    
+	    if (EARTH->options->lratio->counter > 0)
+	      print_lratio_test (EARTH, &Gmax);
+	    if (options->aic)
+	      akaike_information (EARTH, &Gmax);
+	    
+	    profile_tables (options, EARTH, &Gmax);
+	  }
 #else
-	  if (!options->bayes_infer)
-	    {
-	      profile_tables (options, EARTH, &Gmax);
-	    }
+	if (!options->bayes_infer)
+	  {
+	    profile_tables (options, EARTH, &Gmax);
+	  }
 #endif /*INTEGRATEDLIKE*/
-        }
+      }
 #endif /* SLOWNET */
-	
+    
 #ifdef MPI
     if (myID == MASTER)
-        {
+      {
 #endif
-	  // print marginal likelihoods
-	  if(EARTH->options->bayes_infer)
-	    {
-	      print_bayesfactor(EARTH->outfile, universe,options);
-	    }
-
-	  // printing of MCMC run characteristica
-
-	  if(EARTH->options->bayes_infer)
-	    {
-	      fprintf(EARTH->outfile,"MCMC run characteristics\n");
-	      fprintf(EARTH->outfile,"========================\n\n");
-	      bayes_print_accept(EARTH->outfile,EARTH);
+	// print marginal likelihoods
+	if(EARTH->options->bayes_infer)
+	  {
+	    print_bayesfactor(EARTH->outfile, universe,options);
+	  }
+	
+	// printing of MCMC run characteristica
+	
+	if(EARTH->options->bayes_infer)
+	  {
+	    fprintf(EARTH->outfile,"MCMC run characteristics\n");
+	    fprintf(EARTH->outfile,"========================\n\n");
+	    bayes_print_accept(EARTH->outfile,EARTH);
 #ifdef PRETTY
-	      pdf_bayes_print_accept(EARTH);
+	    pdf_bayes_print_accept(EARTH);
 #endif
-	      fprintf(EARTH->outfile,"Autocorrelation and Effective sample size\n");
-	      fprintf(EARTH->outfile,"-------------------------------------------------------------------\n\n");
-	      print_param_eff_size(EARTH->outfile,EARTH,EARTH->numpop2 + EARTH->bayes->mu * EARTH->loci + 1,2,EARTH->auto_archive, EARTH->ess_archive);
+	    fprintf(EARTH->outfile,"Autocorrelation and Effective sample size\n");
+	    fprintf(EARTH->outfile,"-------------------------------------------------------------------\n\n");
+	    print_param_eff_size(EARTH->outfile,EARTH,EARTH->numpop2 + EARTH->bayes->mu * EARTH->loci + 1,2,EARTH->auto_archive, EARTH->ess_archive);
 #ifdef PRETTY
-	      pdf_bayes_print_ess(EARTH);
+	    pdf_bayes_print_ess(EARTH);
 #endif
-	    }
-
-	  if(strchr("ae",EARTH->options->burnin_autostop))
+	  }
+	
+	if(strchr("ae",EARTH->options->burnin_autostop))
 	  {
 	    print_burnin_stop(EARTH->outfile, universe, options);
 	  }
-
-	  if(EARTH->options->progress)
-	    {
-	      if(EARTH->options->bayes_infer)
-		{
-		  fprintf(stdout,"\nMCMC run characteristics: Autocorrelation and Effective sample size\n");
-		  fprintf(stdout,"-------------------------------------------------------------------\n\n");
-		  print_param_eff_size(stdout,EARTH,EARTH->numpop2+ EARTH->bayes->mu * EARTH->loci + 1,2,
-				       EARTH->auto_archive, EARTH->ess_archive);
-
-		  print_bayesfactor(stdout, universe,options);
-
-		}
-	    }
-	  if(EARTH->options->treeinmemory)
-	    {
-	      for(locus=0;locus<EARTH->loci; locus++)
-		{
-		  fprintf(EARTH->treefile,"%s", EARTH->treespace[locus]);
-		}
-	    }
+	
+	if(EARTH->options->progress)
+	  {
+	    if(EARTH->options->bayes_infer)
+	      {
+		fprintf(stdout,"\nMCMC run characteristics: Autocorrelation and Effective sample size\n");
+		fprintf(stdout,"-------------------------------------------------------------------\n\n");
+		print_param_eff_size(stdout,EARTH,EARTH->numpop2+ EARTH->bayes->mu * EARTH->loci + 1,2,
+				     EARTH->auto_archive, EARTH->ess_archive);
+		
+		print_bayesfactor(stdout, universe,options);
+		
+	      }
+	  }
+	if(EARTH->options->treeinmemory)
+	  {
+	    for(locus=0;locus<EARTH->loci; locus++)
+	      {
+		fprintf(EARTH->treefile,"%s", EARTH->treespace[locus]);
+	      }
+	  }
 #ifdef PRETTY
-	  pdf_print_end_time(&page_height);
-	  // write out to PDF file
-	  pdf_write_file(options);
+	pdf_print_end_time(&page_height);
+	// write out to PDF file
+	pdf_write_file(options);
 #endif
-            print_finish (EARTH, outfilepos);
-            // closing all files 
+	print_finish (EARTH, outfilepos);
+	// closing all files 
 #ifdef MAC
-            finish_mac (options, data);
+	finish_mac (options, data);
 #endif
-            
-            exit_files (EARTH, data, options);
+	
+	exit_files (EARTH, data, options);
 #ifdef MPI
 #    ifndef SLOWNET
-            mpi_send_stop (EARTH); //stop workers
-            // printf("%i> at barrier in slownet-main before finalize\n", myID);        
+	mpi_send_stop (EARTH); //stop workers
+	// printf("%i> at barrier in slownet-main before finalize\n", myID);        
 #    endif
-        }
-        MYMPIBARRIER (comm_world);
-        MPI_Finalize ();
+      }
+    MYMPIBARRIER (comm_world);
+    MPI_Finalize ();
 #endif /*MPI*/
-	//	myfree(seed);
-	//myfree(newseed);
-	//myfree(generator);
-	//free_universe(universe, usize, options);
-	//destroy_data(data);
-	//destroy_options(options);
-	// for debugging with MallocDebug on macosx
-	#ifdef MACMALLOCDEBUG
-	while(TRUE)
-	 {
-	  sleep(1);
-	} //end for debugging
-	#endif
-        return 0;
+    //	myfree(seed);
+    //myfree(newseed);
+    //myfree(generator);
+    //free_universe(universe, usize, options);
+    //destroy_data(data);
+    //destroy_options(options);
+    // for debugging with MallocDebug on macosx
+#ifdef MACMALLOCDEBUG
+    while(TRUE)
+      {
+	sleep(1);
+      } //end for debugging
+#endif
+    return 0;
 }				/* main end */
 
 ///
@@ -2349,6 +2263,9 @@ void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options)
   MYREAL heat0 = 1.;
   MYREAL heat1 = 1.;
   MYREAL bfsum = 0.;
+  MYREAL bfsum2 = 0.;
+  MYREAL approxlsum = 0.;
+  MYREAL intercept = 0.;
   MYREAL hsum = 0.;
   MYREAL asum = 0.;
   MYREAL lsum;
@@ -2381,15 +2298,33 @@ void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options)
 		}
 #endif
 	      lsum += (heat0 - heat1) * ((EARTH->bf[locus * hc + t-1] + EARTH->bf[locus * hc + t]) * 0.5);
+#ifdef NEWVERSION
 	      printf("%i> sum[%li]=%f temp=(%f %f) values=(%f %f)\n",myID,t,lsum,heat0,heat1,EARTH->bf[locus * hc + t-1],EARTH->bf[locus * hc + t]);
+#endif
 	    }
-	  //	  fprintf(stdout,"Thermo[%li]=%f\n",locus, log(lsum) + EARTH->bfscale[locus]);
-	  fprintf(stdout,"Thermo[%li]=%f\n",locus, lsum);
+	  //	  (x2 y1 - x1 y2)/(x1 - x2)
+	  // this last addition to the lsum calculates the chunk between the last temperature and 
+	  // the infinitely hot temperature as a linear approximation of the the second hottest temperature
+	  // this is certainly rough, but in simulations with 3 populations one can see that with large number
+	  // of temperatures this looks reasonable, and one can approximate the integral more accurately with 
+	  // with only a few columns.
+#ifdef NEWVERSION
+	  intercept = (heat0 * EARTH->bf[locus * hc + t-1] - heat1 * EARTH->bf[locus * hc + t-2])/(heat0 - heat1);
+	  approxlsum = lsum + heat1 * ((EARTH->bf[locus * hc + t-1] + intercept) * 0.5);
+
+	  fprintf(stdout,"Thermo[%li]=%f (%f) [%f]\n",locus, lsum, approxlsum, intercept);
 	  //	  bfsum += log(lsum) + EARTH->bfscale[locus];
+	  bfsum2 += approxlsum;
+#endif
 	  bfsum += lsum; //+ EARTH->bfscale[locus];
 	}
+#ifdef NEWVERSION
+      fprintf(file,"(1) Thermodynamic integration: log(Prob(D|Model))=%f (%f) %s\n", bfsum, bfsum2,  
+      	      options->adaptiveheat ? "(adaptive heating -> value may be wrong)" : "");
+#else
       fprintf(file,"(1) Thermodynamic integration: log(Prob(D|Model))=%f %s\n", bfsum,  
       	      options->adaptiveheat ? "(adaptive heating -> value may be wrong)" : "");
+#endif
     }
   else
     {
@@ -2404,7 +2339,7 @@ void print_bayesfactor(FILE *file, world_fmt **universe, option_fmt * options)
       //printf(" %f %f\n",EARTH->hm[locus],EARTH->am[locus]);
       if(EARTH->data->skiploci[locus])
 	continue;
-      fprintf(stdout,"    Harmonic[%li]=%f\n",locus, EARTH->hmscale[locus] - log (EARTH->hm[locus]));
+      //      fprintf(stdout,"    Harmonic[%li]=%f\n",locus, EARTH->hmscale[locus] - log (EARTH->hm[locus]));
       hsum +=  EARTH->hmscale[locus] - log (EARTH->hm[locus]);
     }
   fprintf(file,"(2) Harmonic mean:             log(Prob(D|Model))=%f\n",hsum);
@@ -2436,6 +2371,9 @@ void calculate_BF(world_fmt **universe, option_fmt *options)
   long i;
   MYREAL xx, xx2;
   //  MYREAL logprior;
+#ifdef THERMOCHECK
+  static long counter=0;
+#endif
   long locus = universe[0]->locus;
   long hc = options->heated_chains;
   if(universe[0]->data->skiploci[locus])
@@ -2444,28 +2382,15 @@ void calculate_BF(world_fmt **universe, option_fmt *options)
     return;
   EARTH->am[locus] += 1;
   locus = EARTH->locus;
-  if(options->heating)
-    {
-      for (i = 0; i < hc; i++)
-	{
-	  xx = universe[i]->likelihood[universe[i]->G];
-#ifdef THERMOCHECK
-	  fprintf(stderr,"\n@@@T %li %10.10f %10.10f ",locus, universe[i]->heat, xx);
-#endif
-	  EARTH->bf[locus * hc + i] += (xx - EARTH->bf[locus * hc + i])/ (EARTH->am[locus]);
-#ifdef THERMOCHECK
-	  fprintf(stderr,"%f\n", 	  EARTH->bf[locus * hc + i]);
-#endif
-	}
-    }
   xx = EARTH->likelihood[EARTH->G];
+
+#ifdef THERMOCHECK
+  counter++;
+#endif
+
   if(xx <= -HUGE)
     return;
 
-#ifdef THERMOCHECK
-  fprintf(stderr,"\n@@@H %li %10.10f %10.10f %10.10f\n",locus, EARTH->heat, xx, EARTH->hmscale[locus]);
-#endif
-  
   if(xx > EARTH->hmscale[locus])
     {
       //      EARTH->hm[locus] += EXP(EARTH->hmscale[locus] - xx);
@@ -2480,6 +2405,32 @@ void calculate_BF(world_fmt **universe, option_fmt *options)
       //      EARTH->hm[locus] += 1.;
       EARTH->hm[locus] += (1. - EARTH->hm[locus])/ (EARTH->am[locus]);
     }
+
+#ifdef THERMOCHECK
+  if(options->mixplot)
+    fprintf(universe[0]->options->mixfile,"@BF %li %li %10.10f %10.10f",counter, locus, EARTH->heat, xx);
+  //, EARTH->hmscale[locus]);
+#endif
+
+  if(options->heating)
+    {
+      for (i = 0; i < hc; i++)
+	{
+	  xx = universe[i]->likelihood[universe[i]->G];
+#ifdef THERMOCHECK
+	  if(options->mixplot)
+	    fprintf(universe[0]->options->mixfile," @T %10.10f %10.10f", universe[i]->heat, xx);
+#endif
+	  EARTH->bf[locus * hc + i] += (xx - EARTH->bf[locus * hc + i])/ (EARTH->am[locus]);
+	  //#ifdef THERMOCHECK
+	  //fprintf(universe[0]->options->mixfile,"%f\n", 	  EARTH->bf[locus * hc + i]);
+	  //#endif
+	}
+    }
+#ifdef THERMOCHECK
+  if(options->mixplot)
+  fprintf(universe[0]->options->mixfile,"\n");
+#endif
 }
 
 #ifdef BFDEBUG
@@ -2646,3 +2597,116 @@ change_longsum_times (world_fmt * world)
 }
 
 #endif /*LONGSUM*/
+
+///
+/// check_parmfile checks what is called and also whether we should honor the menu=YES in the file
+/// user uses another parmfile than the default when there is a parameter associated with the program call
+/// this function checks the first two line of the file to find out whether this is a parmfile or potentially
+/// a datafile/ 
+/// The addition of an option to override the menu command in the parmfile
+/// migrate-n -menu ==> use menu independent of the parmfile setting
+/// migrate-n -nomenu ==> does use menu even if parmfile says so
+
+boolean  check_parmfile(long argcount, char **arguments, char *parmfilename)
+{
+  int argument=0;
+  boolean  usemenu = OVERRIDE_NO;
+  if (argcount > 1)			
+    {
+      argument = 1;
+      while(argument < argcount)
+	{
+	  //fprintf(stderr,"<|%s|>\n",argv[argument]);
+	  //fflush(stderr);
+	  if(arguments[argument][0]!='-')
+	    {
+	      strncpy (parmfilename, arguments[argument], 
+		       (long) strlen (arguments[argument]) + 1);
+	    }
+	  else
+	    {
+	      if(strcmp(arguments[argument],"-menu")==0)
+		{
+		  usemenu = OVERRIDE_MENU;
+		}
+	      else
+		{
+		  if(strcmp(arguments[argument],"-nomenu")==0)
+		    {
+		      usemenu = OVERRIDE_NOMENU;
+		    }
+		}
+	    }
+	  argument++;
+	}
+    }
+  return usemenu;
+}
+
+/// set the menu overrider 
+boolean set_usemenu(boolean usemenu, boolean fromparmfile)
+{
+  switch(usemenu)
+    {
+    case OVERRIDE_MENU:
+      return TRUE;
+      break;
+    case OVERRIDE_NOMENU:
+      return FALSE;
+      break;
+    default:
+      break;
+    }
+  return fromparmfile;
+} 
+
+/// checks the settings of the number of long an short chain for bayes options and resets useless settings
+void check_bayes_options(option_fmt *options)
+{
+  if (options->bayes_infer)
+    {
+      if(options->schains>0)
+	{
+	  //		fprintf(stdout,"NOTICE: with Bayesian inference no short chains are allowed, setting them to ZERO\n");
+	  options->schains = 0;
+	}
+      if(options->lchains>1 || options->lchains < 1)
+	{
+	  fprintf(stdout,"NOTICE: with Bayesian inference, most efficient runs are with 1 long chain,\nsetting the long chain to 1\n");
+	  options->lchains = 1;
+	};
+    }
+}
+
+void reset_bayesmdimfile(world_fmt *world, option_fmt *options)
+{
+  long locus=0;
+  if(world->options->has_bayesmdimfile)
+    {
+      get_bayeshist (world, options); // this is transferring some material but
+      // the parameter file is not filled in anymore [-> small data block]
+      // save parameters in file and reload
+      if(myID==MASTER)
+	{
+	  FClose(world->bayesmdimfile);
+	  openfile(&world->bayesmdimfile, options->bayesmdimfilename,"r+",NULL);
+	  read_bayes_fromfile(world->bayesmdimfile,world, options);
+	  for(locus=0;locus<world->loci;locus++)
+	    {
+	      if(world->data->skiploci[locus])
+		continue;
+	      if(world->bayes->histogram[locus].results == NULL)
+		{
+		  world->data->skiploci[locus] = TRUE;
+		  continue;
+		}
+	      calc_hpd_credibility(world->bayes, locus, world->numpop2 + world->bayes->mu);
+	    }
+	}
+    }
+  else
+    {
+      // keep everything in RAM
+      get_bayeshist (world, options);
+    }
+}
