@@ -22,7 +22,7 @@ Copyright 2003-2007 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: random.c 767 2007-07-15 18:11:13Z beerli $
+$Id: random.c 1226 2008-04-02 12:38:07Z beerli $
 -------------------------------------------------------*/
 /* \file random.c */
 #include "sighandler.h"
@@ -433,8 +433,15 @@ unsigned long int random_seed()
   
   if ((devrandom = fopen("/dev/random","r")) == NULL) 
     {
+      //#ifndef WINDOWS
       gettimeofday(&tv,0);
+      printf("in random_seed() %li + %li\n",tv.tv_sec,tv.tv_usec);
       seed = tv.tv_sec + tv.tv_usec;
+      //#else
+      //time(&seed);
+      //      seed = (unsigned int) rand();
+      //printf("in random_seed() %li\n",seed);
+      //#endif
     }
   else 
     {
