@@ -5,7 +5,7 @@
  -------------------------------------------------------                        
  R e p o r t e r   R O U T I N E  reports things progress=True or verbose
  
-                                                                                                               Peter Beerli
+ Peter Beerli
  beerli@scs.fsu.edu
  
 Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
@@ -16,7 +16,7 @@ Copyright 2003-2007 Peter Beerli, Tallahassee FL
  works and are not responsible for any damage you may cause or have.
  
  
-$Id: reporter.c 1105 2008-01-03 22:27:33Z beerli $
+$Id: reporter.c 1220 2008-03-28 01:36:29Z beerli $
  
 -------------------------------------------------------*/
 /* \file reporter.c 
@@ -321,16 +321,19 @@ calc_allgelmanb (MYREAL *gelmanb, MYREAL *mc, MYREAL *chainmeans, long *nmeans,
 /// collect the autocorrelation values and the ESS values
 void collect_eff_values(world_fmt *world)
 {
+  static long n=1;
   const long nn = world->numpop2 + world->bayes->mu * world->loci + 1;// One is for Log(Prob(Data|Model)
   long i;
-  long maxrep = (world->options->replicate == TRUE) ? ((world->options->replicatenum > 0) ? 
-						       world->options->replicatenum  : world->options->lchains ) : 1;
+  // long maxrep = (world->options->replicate == TRUE) ? ((world->options->replicatenum > 0) ? 
+  //		      world->options->replicatenum  : world->options->lchains ) : 1;
 
   for(i=0;i<nn; i++)
     {
-      world->auto_archive[i] += world->autocorrelation[i]/maxrep/world->loci;
+      world->auto_archive[i] += (world->autocorrelation[i] - world->auto_archive[i])/n;
       world->ess_archive[i] += world->effective_sample[i];
     }
+  n++;
+  //printf("%i> %li autoarchive %f autocorr %f n=%li\n", myID, world->rep,  world->auto_archive[0], world->autocorrelation[0], nn);
 }
 
 
