@@ -16,7 +16,7 @@
  works and are not responsible for any damage you may cause or have.
  
  
- $Id: sequence.c 1087 2007-12-20 19:28:34Z beerli $
+ $Id: sequence.c 1157 2008-02-15 21:31:13Z beerli $
  
 -------------------------------------------------------*/
 /* \file sequence.c
@@ -1820,12 +1820,11 @@ snp_invariants (contribarr invariants, world_fmt *world, long locus, phenotype x
     seqmodel_fmt *seq =  world->data->seq;
     MYREAL summ;
 
-
+    sitelike *val;
     long i, j;
 
     node *p;
     opt = world->options;
-    p = crawlback (world->root->next);
     summ = 0.0;
     /* snp invariants */
     for (j = 0; j < opt->rcategs; j++)
@@ -1833,12 +1832,13 @@ snp_invariants (contribarr invariants, world_fmt *world, long locus, phenotype x
 	invariants[j] = 0.0;
 	for (i = seq->endsite - seq->addon ; i < seq->endsite; i++)
 	  {
+	    val = &(x1[i][j]);
             invariants[j] +=
-	      (seq->freqa * (*x1)[i][0] + seq->freqc * (*x1)[i][1] +
-	       seq->freqg * (*x1)[i][2] + seq->freqt * (*x1)[i][3]);
+	      (seq->freqa * (*val)[0] + seq->freqc * (*val)[1] +
+	       seq->freqg * (*val)[2] + seq->freqt * (*val)[3]);
 	  }
 	invariants[j] = 1 - invariants[j];
-    }
+      }
     //    printf("invariant0=%f\n",invariants[0]);
 }    /* snp_invariants*/
 
@@ -1848,7 +1848,10 @@ treelike_snp (world_fmt * world, long locus)
     worldoption_fmt *opt;
     seqmodel_fmt *seq =  world->data->seq;
     MYREAL scale;
-    contribarr tterm, invariants, like, nulike;
+    contribarr tterm;
+    contribarr invariants;
+    contribarr like;
+    contribarr nulike;
     MYREAL summ, sum2, sumc, sumterm, lterm;
     long i, j, k, lai;
 
