@@ -14,7 +14,7 @@
 Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
 Copyright 2003-2006 Peter Beerli, Tallahassee FL
  
-$Id: tools.h 691 2007-04-27 13:21:02Z beerli $
+$Id: tools.h 1088 2007-12-21 20:50:44Z beerli $
 -------------------------------------------------------*/
 
 #include "migration.h"
@@ -53,6 +53,14 @@ extern void onepass_mean_std_start(MYREAL *mean, MYREAL *std, long *n);
 extern void onepass_mean_std_calc(MYREAL *mean, MYREAL *std, long *n, MYREAL x);
 extern void onepass_mean_std_end(MYREAL *mean, MYREAL *std, long *n);
 
+extern boolean traverse_check_id(node *theNode, long id);
+extern  void start_node_collection(world_fmt *world);
+extern void stop_node_collection(world_fmt *world);
+extern void collect_nodelet(world_fmt *world, node *p);
+extern node *  dispense_nodelet(world_fmt *world);
+extern void swap_node_collection(world_fmt * tthis, world_fmt * that);
+
+
 extern float fast_log(float vval);
 extern MYINLINE double fast_exp(double y); 
 
@@ -64,8 +72,10 @@ extern void upper(char *from, char **to);
 /* vector initialization and calc*/
 extern void doublevec1d (MYREAL **v, long size);
 extern void doublevec2d (MYREAL ***v, long size1, long size2);
+extern void floatvec2d (float ***v, long size1, long size2);
 extern void charvec2d (char ***v, long size1, long size2);
 extern void free_doublevec2d (MYREAL **v);
+extern void free_floatvec2d (float **v);
 extern void free_charvec2d (char **v);
 extern void setdoublevec1d (MYREAL **v, MYREAL *w, long size);
 extern void add_vector (MYREAL *result, MYREAL *v, long size);
@@ -82,6 +92,7 @@ extern void write_savesum (world_fmt * world);
 
 /* string manipulation */
 extern void translate (char *text, char from, char to);
+extern void unpad (char *text, char removechars[]);
 extern void get_next_word(char **instring, char *delimiters, char **nextword);
 extern long count_words (char *text);
 extern void read_word(FILE *infile, char *word);
@@ -111,5 +122,8 @@ extern void sprint_line (char *buffer, char c, long nn, long flag);
 /* reading from char * buffer */
 char sgetc (char **buffer);
 char *sgets (char *s, int size, char **stream);
+#ifdef CAUTIOUS
+extern boolean cautious;
+#endif
 
 #endif /*TOOLS_INCLUDE */
